/*******************************************************************************
*
* E M B E D D E D   W I Z A R D   P R O J E C T
*
*                                                Copyright (c) TARA Systems GmbH
*                                    written by Paul Banach and Manfred Schweyer
*
********************************************************************************
*
* This software is delivered "as is" and shows the usage of other software
* components. It is provided as an example software which is intended to be
* modified and extended according to particular requirements.
*
* TARA Systems hereby disclaims all warranties and conditions with regard to the
* software, including all implied warranties and conditions of merchantability
* and non-infringement of any third party IPR or other rights which may result
* from the use or the inability to use the software.
*
********************************************************************************
*
* DESCRIPTION:
*   This file is part of the interface (glue layer) between an Embedded Wizard
*   generated UI application and the board support package (BSP) of a dedicated
*   target.
*   Please note: The implementation of this module is partially based on
*   examples that are provided within the STM32 cube firmware. In case you want
*   to adapt this module to your custom specific hardware, please adapt the
*   hardware initialization code according your needs or integrate the generated
*   initialization code created by using the tool CubeMX.
*   This template is responsible to initialize the display hardware of the board
*   and to provide the necessary access to update the display content.
*   The color format of the framebuffer has to correspond to the color format
*   of the Graphics Engine.
*
*   Important: This file is intended to be used as a template. Please adapt the
*   implementation according your particular hardware.
*
*******************************************************************************/

#include "ewconfig.h"
#include "stm32u5x9j_discovery.h"

#include <string.h>

#include "ewrte.h"

#include "ew_bsp_clock.h"
#include "ew_bsp_display.h"
#include "ew_bsp_os.h"


#if EW_USE_DOUBLE_BUFFER == 1

  static volatile uint32_t    CurrentFramebuffer = 0;
  static volatile uint32_t    PendingFramebuffer = 0;

#else

  static volatile int         CurrentLine = -1;
  static volatile int         PendingLine = -1;

#endif

// msy: temporary workaround, since threadx semaphores behave other than expected
#undef EW_USE_OPERATING_SYSTEM
#define EW_USE_OPERATING_SYSTEM 0

#if EW_USE_OPERATING_SYSTEM == 1

  static XSemaphoreHandle     LcdUpdateSemaphore = 0;

#endif


/* Pixel Format configuration: translate framebuffer color format into LTDC mode */
#if ( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_RGBA8888 )
  #define LTDC_PIXEL_FORMAT  LTDC_PIXEL_FORMAT_ARGB8888
#elif ( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_RGB888 )
  #define LTDC_PIXEL_FORMAT  LTDC_PIXEL_FORMAT_RGB888
#elif ( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_RGB565 )
  #define LTDC_PIXEL_FORMAT  LTDC_PIXEL_FORMAT_RGB565
#else
  #error "EW_FRAME_BUFFER_COLOR_FORMAT not supported"
#endif

#if EW_USE_DOUBLE_BUFFER == 0
  #error "Double buffering required for STM32U599-Discovery!"
#endif


#define LAYER_INDEX           0

#if USE_GFXMMU == 1

/* Pixel Format configuration: translate framebuffer color format into LTDC mode */
#if ( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_RGBA8888 )
#define BSP_LCD_PIXEL_FORMAT    LTDC_PIXEL_FORMAT_ARGB8888
#define BSP_LCD_BYTE_PER_PIXEL  4
#define BSP_LCD_PHYS_FB_SIZE    482336
#elif ( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_RGB888 )
#define BSP_LCD_PIXEL_FORMAT    LTDC_PIXEL_FORMAT_RGB888
#define BSP_LCD_BYTE_PER_PIXEL  3
#define BSP_LCD_PHYS_FB_SIZE    364000
#elif ( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_RGB565 )
#define BSP_LCD_PIXEL_FORMAT    LTDC_PIXEL_FORMAT_RGB565
#define BSP_LCD_BYTE_PER_PIXEL  2
#define BSP_LCD_PHYS_FB_SIZE    244064
#else
  #error "selected color format not supported"
#endif

#define EW_FRAME_BUFFER_WIDTH    (3072 / BSP_LCD_BYTE_PER_PIXEL)
#define EW_FRAME_BUFFER_HEIGHT   EW_DISPLAY_HEIGHT

/* set frame buffer to the GFXMMU virtual frambuffer 0 */
#define EW_FRAME_BUFFER_ADDR     (void*)GFXMMU_VIRTUAL_BUFFER0_BASE

#if EW_USE_DOUBLE_BUFFER == 1
#define EW_DOUBLE_BUFFER_ADDR     (void*)GFXMMU_VIRTUAL_BUFFER1_BASE
#else
#define EW_DOUBLE_BUFFER_ADDR     0
#endif

#define EW_FRAME_BUFFER_ADDR     (void*)GFXMMU_VIRTUAL_BUFFER0_BASE

#if EW_USE_DOUBLE_BUFFER == 1
#define EW_DOUBLE_BUFFER_ADDR     (void*)GFXMMU_VIRTUAL_BUFFER1_BASE
#else
#define EW_DOUBLE_BUFFER_ADDR     0
#endif

#else

//no GFXMMU
#define EW_FRAME_BUFFER_SIZE  EW_FRAME_BUFFER_WIDTH * EW_FRAME_BUFFER_HEIGHT * EW_FRAME_BUFFER_DEPTH
#define EW_FRAME_BUFFER_ADDR  (unsigned int)FrameBuffer

static uint64_t FrameBuffer[ EW_FRAME_BUFFER_SIZE/8 ];

#if EW_USE_DOUBLE_BUFFER == 1
  #define EW_DOUBLE_BUFFER_ADDR  (unsigned int)DoubleBuffer

  static uint64_t DoubleBuffer[ EW_FRAME_BUFFER_SIZE/8 ];
#else
  #define EW_DOUBLE_BUFFER_ADDR  0
#endif
#endif


extern DSI_HandleTypeDef hdsi;

#if USE_GFXMMU == 1
extern GFXMMU_HandleTypeDef hgfxmmu;
#endif

extern LTDC_HandleTypeDef hltdc;

#define hgfxmmu_eval hgfxmmu
#define hdsi_handle hdsi
#define hltdc_handle hltdc


void HAL_LTDC_LineEventCallback( LTDC_HandleTypeDef* aLtdc )
{
  #if EW_USE_DOUBLE_BUFFER == 1

    /* as soon as V-sync interrupt occurs, no buffer is pending */
    if ( PendingFramebuffer )
    {
      #if EW_USE_OPERATING_SYSTEM == 1
        EwBspOsSemaphoreRelease( LcdUpdateSemaphore );
      #else
        PendingFramebuffer = 0;
      #endif
    }

    /* program next V-sync */
    HAL_LTDC_ProgramLineEvent( aLtdc, 0 );

  #else

    /* update current line number */
    CurrentLine = PendingLine;

    #if EW_USE_OPERATING_SYSTEM == 1
      EwBspOsSemaphoreRelease( LcdUpdateSemaphore );
    #endif

  #endif
}


/* Helper function to sync on a certain line number updated by the display.
   This function is necessary when the system is used in single framebuffer mode. */
#if EW_USE_DOUBLE_BUFFER == 0
static void SyncOnLine( int aLine )
{
  /* add the vsync area and the vertical back porch */
  aLine = aLine + hltdc.Init.AccumulatedVBP + 1;

  /* ensure that requested line is still inside active area or vertical front porch */
  if ( aLine > hltdc.Init.TotalHeigh + 1 )
    aLine = 0;

  CurrentLine = -1;
  PendingLine = aLine;

  CPU_LOAD_SET_IDLE();

  /* program line number of next field */
  HAL_LTDC_ProgramLineEvent( &hltdc, aLine );

  #if EW_USE_OPERATING_SYSTEM == 1
    EwBspOsSemaphoreWait( LcdUpdateSemaphore, 1000 );
  #else

    while( aLine != CurrentLine )
      ;

  #endif

  CPU_LOAD_SET_ACTIVE();
}
#endif


/*******************************************************************************
* FUNCTION:
*   EwBspDisplayInit
*
* DESCRIPTION:
*   The function EwBspDisplayInit initializes the display hardware and returns
*   the display parameter.
*
* ARGUMENTS:
*   aGuiWidth,
*   aGuiHeight   - Size of the GUI in pixel.
*   aDisplayInfo - Display info data structure.
*
* RETURN VALUE:
*   Returns 1 if successful, 0 otherwise.
*
*******************************************************************************/
int EwBspDisplayInit( int aGuiWidth, int aGuiHeight, XDisplayInfo* aDisplayInfo )
{
  EW_UNUSED_ARG( aGuiWidth );
  EW_UNUSED_ARG( aGuiHeight );

  /* check and clean display info structure */
  if ( !aDisplayInfo )
    return 0;

  memset( aDisplayInfo, 0, sizeof( XDisplayInfo ));

  #if EW_USE_DOUBLE_BUFFER == 1

    /* Configure the vsync */
    if ( HAL_LTDC_ProgramLineEvent( &hltdc, 0 ) != HAL_OK )
      EwPrint( "EwBspDisplayInit: Could not configure interrupt for vsync!\n" );

  #endif

  HAL_LTDC_SetPixelFormat(&hltdc, LTDC_PIXEL_FORMAT, LAYER_INDEX );
  HAL_LTDC_SetAddress( &hltdc, (uint32_t)EW_FRAME_BUFFER_ADDR, LAYER_INDEX );

  #if EW_USE_OPERATING_SYSTEM == 1

    /* create the LCD update semaphore */
    LcdUpdateSemaphore = EwBspOsSemaphoreCreate( 1, 1 );

  #endif

  /* return the current display configuration */
  aDisplayInfo->FrameBuffer    = (void*)EW_FRAME_BUFFER_ADDR;
  aDisplayInfo->DoubleBuffer   = (void*)EW_DOUBLE_BUFFER_ADDR;
  aDisplayInfo->BufferWidth    = EW_FRAME_BUFFER_WIDTH;
  aDisplayInfo->BufferHeight   = EW_FRAME_BUFFER_HEIGHT;
  aDisplayInfo->DisplayWidth   = EW_DISPLAY_WIDTH;
  aDisplayInfo->DisplayHeight  = EW_DISPLAY_HEIGHT;

  #if EW_USE_DOUBLE_BUFFER == 1
    aDisplayInfo->UpdateMode   = EW_BSP_DISPLAY_UPDATE_NORMAL;
  #else
    aDisplayInfo->UpdateMode   = EW_BSP_DISPLAY_UPDATE_PARTIAL;
  #endif

  return 1;
}


/*******************************************************************************
* FUNCTION:
*   EwBspDisplayDone
*
* DESCRIPTION:
*   The function EwBspDisplayDone deinitializes the display hardware.
*
* ARGUMENTS:
*   aDisplayInfo - Display info data structure.
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspDisplayDone( XDisplayInfo* aDisplayInfo )
{
  EW_UNUSED_ARG( aDisplayInfo );

  #if EW_USE_OPERATING_SYSTEM == 1

    /* destroy the LCD semaphore */
    EwBspOsSemaphoreDestroy( LcdUpdateSemaphore );

  #endif
}


/*******************************************************************************
* FUNCTION:
*   EwBspDisplayGetUpdateArea
*
* DESCRIPTION:
*   The function EwBspDisplayGetUpdateArea returns the next update area
*   depending on the selected display mode:
*   In case of a synchroneous single-buffer, the function has to return the
*   the rectangular areas that correspond to the horizontal stripes (fields)
*   of the framebuffer.
*   In case of a scratch-pad buffer, the function has to return the subareas
*   that fit into the provided update rectangle.
*   During each display update, this function is called until it returns 0.
*
* ARGUMENTS:
*   aUpdateRect - Rectangular area which should be updated (redrawn).
*
* RETURN VALUE:
*   Returns 1 if a further update area can be provided, 0 otherwise.
*
*******************************************************************************/
int EwBspDisplayGetUpdateArea( XRect* aUpdateRect )
{
  #if EW_USE_DOUBLE_BUFFER == 0

    static int field = 0;

    /* check if last field is already reached */
    if ( field >= EW_NUMBER_OF_FIELDS )
    {
      field = 0;
      return 0;
    }

    /* determine rectangular area of current field */
    #if EW_SURFACE_ROTATION == 0
      *aUpdateRect = EwNewRect( 0, field * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS,
        EW_FRAME_BUFFER_WIDTH, ( field + 1 ) * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS );
    #endif

    #if EW_SURFACE_ROTATION == 90
      *aUpdateRect = EwNewRect( field * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS, 0,
        ( field + 1 ) * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS, EW_FRAME_BUFFER_WIDTH );
    #endif

    #if EW_SURFACE_ROTATION == 180
      *aUpdateRect = EwNewRect( 0, EW_FRAME_BUFFER_HEIGHT - ( field + 1 ) * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS,
        EW_FRAME_BUFFER_WIDTH, EW_FRAME_BUFFER_HEIGHT - field * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS );
    #endif

    #if EW_SURFACE_ROTATION == 270
      *aUpdateRect = EwNewRect( EW_FRAME_BUFFER_HEIGHT - ( field + 1 ) * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS,
        0, EW_FRAME_BUFFER_HEIGHT - field * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS, EW_FRAME_BUFFER_WIDTH );
    #endif

    /* next field */
    field++;

    /* sync on start line of next field to ensure save drawing operation */
    SyncOnLine( field * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS );

    return 1;

  #else

    return 0;

  #endif
}


/*******************************************************************************
* FUNCTION:
*   EwBspDisplayWaitForCompletion
*
* DESCRIPTION:
*   The function EwBspDisplayWaitForCompletion is called from the Graphics Engine
*   to ensure that all pending activities of the display system are completed, so
*   that the rendering of the next frame can start.
*   In case of a double-buffering system, the function has to wait until the
*   V-sync has occured and the pending buffer is used by the display controller.
*   In case of an external display controller, the function has to wait until
*   the transfer (update) of the graphics data has been completed and there are
*   no pending buffers.
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspDisplayWaitForCompletion( void )
{
  #if EW_USE_DOUBLE_BUFFER == 1

    /* return immediately if no pending framebuffer */
    if ( PendingFramebuffer == 0 )
      return;

    CPU_LOAD_SET_IDLE();

    #if EW_USE_OPERATING_SYSTEM == 1

      /* wait until pending framebuffer is used as current framebuffer and
         use CPU time for other tasks */
      EwBspOsSemaphoreWait( LcdUpdateSemaphore, 1000 );
      PendingFramebuffer = 0;

    #else

      /* wait until pending framebuffer is used as current framebuffer */
      while( PendingFramebuffer )
        ;

    #endif

    CPU_LOAD_SET_ACTIVE();

  #endif
}


/*******************************************************************************
* FUNCTION:
*   EwBspDisplayCommitBuffer
*
* DESCRIPTION:
*   The function EwBspDisplayCommitBuffer is called from the Graphics Engine
*   when the rendering of a certain buffer has been completed.
*   The type of buffer depends on the selected framebuffer concept.
*   If the display is running in a double-buffering mode, the function is called
*   after each buffer update in order to change the currently active framebuffer
*   address. Changing the framebuffer address should be synchronized with V-sync.
*   If the system is using an external graphics controller, this function is
*   responsible to start the transfer of the framebuffer content.
*
* ARGUMENTS:
*   aAddress - Address of the framebuffer to be shown on the display.
*   aX,
*   aY       - Origin of the area which has been updated by the Graphics Engine.
*   aWidth,
*   aHeight  - Size of the area which has been updated by the Graphics Engine.
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspDisplayCommitBuffer( void* aAddress, int aX, int aY, int aWidth, int aHeight )
{
  #if EW_USE_DOUBLE_BUFFER == 1

    /* change address within layer configuration structure */
    if ( HAL_LTDC_SetAddress( &hltdc, (uint32_t)aAddress, LAYER_INDEX )  != HAL_OK )
      EwPrint( "EwBspDisplayCommitBuffer: Could not change framebuffer address!\n" );

    /* Remark: Due to LTDC/DSI combination it seems that layer configs are reloaded
       automatically during next V-sync - even though it is configured as immediately */

    /* set pending framebuffer address to be used on next V-sync */
    PendingFramebuffer = (uint32_t)aAddress;

  #endif
}


/*******************************************************************************
* FUNCTION:
*   EwBspDisplaySetClut
*
* DESCRIPTION:
*   The function EwBspDisplaySetClut is called from the Graphics Engine
*   in order to update the hardware CLUT of the current framebuffer.
*   The function is only called when the color format of the framebuffer is
*   Index8 or LumA44.
*
* ARGUMENTS:
*   aClut - Pointer to a color lookup table with 256 entries.
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspDisplaySetClut( unsigned long* aClut )
{
}


/* mli, msy */
